@@ -9,12 +9,12 @@ function(K,probTotal,drift,expectedStoppingTime,secondTimeScaleIsUsed,t,t2,t2max
   FunctionNames=NULL;
   FunctionNamesUpper=NULL;
   FunctionNamesLower=NULL;
-    
+
   ##compute exit probability and cumulative exit probability
   for(i in 1:K)
   {
     resultExitProb[i] <- probExceedingUpper[i]+probExceedingLower[i]
-    
+
     if(i==1)
     {
       cumulativeExitProb[i] <- resultExitProb[i]
@@ -22,17 +22,17 @@ function(K,probTotal,drift,expectedStoppingTime,secondTimeScaleIsUsed,t,t2,t2max
     else
     {
       cumulativeExitProb[i] <- cumulativeExitProb[i-1] + resultExitProb[i]
-    } 
+    }
   }
 
-  
+
   #Set Toplevel
   outTask3Toplevel <- tktoplevel(taskWindow)
   tkwm.title(outTask3Toplevel,paste("-3-  K=",K,", drift parameter=",round(drift,digits=5)))
-  
+
   #Define main Frame
   OutputTask3 <- tkframe(outTask3Toplevel)
-  
+
   #Define subframes
   staticFrame <- tkframe(OutputTask3,relief="groove",borderwidth=0)
   dynamicFrame <- tkframe(OutputTask3,relief="groove",borderwidth=0)
@@ -44,10 +44,10 @@ function(K,probTotal,drift,expectedStoppingTime,secondTimeScaleIsUsed,t,t2,t2max
   upperBoundsFrame <- tkframe(dynamicFrame,relief="groove",borderwidth=2)
   exitProbabilityFrame <- tkframe(dynamicFrame,relief="groove",borderwidth=2)
   cumulativeExitProbFrame <- tkframe(dynamicFrame,relief="groove",borderwidth=2)
-  
+
   #create label with parameter values:
   tkgrid( tklabel(parametersFrame, text=paste("K =",K)),sticky="w")
-  
+
   if(!enterBoundsManually)
   {
     if(!BoundsSymmetry==3)
@@ -58,15 +58,15 @@ function(K,probTotal,drift,expectedStoppingTime,secondTimeScaleIsUsed,t,t2,t2max
     {
       tkgrid( tklabel(parametersFrame, text=paste("alpha - Upper Bounds =",alpha[1])),sticky="w")
       tkgrid( tklabel(parametersFrame, text=paste("alpha - Lower Bounds =",alpha[2])),sticky="w")
-    
+
     }
   }
-  
+
   if(!BoundsSymmetry==3)
   {
     if(enterBoundsManually)
     {
-      tkgrid( tklabel(parametersFrame, text="manually entered Bounds"),sticky="w") 
+      tkgrid( tklabel(parametersFrame, text="manually entered Bounds"),sticky="w")
     }
     else
     {
@@ -75,15 +75,15 @@ function(K,probTotal,drift,expectedStoppingTime,secondTimeScaleIsUsed,t,t2,t2max
                          paste("Hwang-Shih-DeCani Family ( phi =",phi[1],")"),"Exact Pocock Bounds")
 
       # substitute according funtion in output
-      tkgrid( tklabel(parametersFrame, text=paste("Function: ",FunctionNames[[spendingFunctionUsed[1]]])),sticky="w") 
+      tkgrid( tklabel(parametersFrame, text=paste("Function: ",FunctionNames[[spendingFunctionUsed[1]]])),sticky="w")
     }
   }
   else
-  { 
+  {
     if(enterBoundsManually)
     {
       tkgrid( tklabel(parametersFrame, text="Upper Bounds: manually entered "),sticky="w")
-      tkgrid( tklabel(parametersFrame, text="Lower Bounds: manually entered "),sticky="w")      
+      tkgrid( tklabel(parametersFrame, text="Lower Bounds: manually entered "),sticky="w")
     }
     else
     {
@@ -91,25 +91,25 @@ function(K,probTotal,drift,expectedStoppingTime,secondTimeScaleIsUsed,t,t2,t2max
       FunctionNamesUpper <- c("O'Brien-Fleming Type","Pocock Type",paste("Power Family: alpha*t^",phi[1],sep=""),
                               paste("Hwang-Shih-DeCani Family ( phi =",phi[1],")"),"Exact Pocock Bounds")
       FunctionNamesLower <- c("O'Brien-Fleming Type","Pocock Type",paste("Power Family: alpha*t^",phi[2],sep=""),
-                              paste("Hwang-Shih-DeCani Family ( phi =",phi[2],")"),"Exact Pocock Bounds")                      
-       
-      # substitute according funtion in output                     
-      cat("Spending Function for UPPER Bound:","<b>",FunctionNamesUpper[spendingFunctionUsed[1]],"</b>","<br>\n",file = zz)
-      cat("Spending Function for LOWER Bound:","<b>",FunctionNamesLower[spendingFunctionUsed[2]],"</b>","<br>\n",file = zz)      
+                              paste("Hwang-Shih-DeCani Family ( phi =",phi[2],")"),"Exact Pocock Bounds")
+
+      # substitute according funtion in output
+      tkgrid( tklabel(parametersFrame, text=paste("Function - Upper Bounds: ",FunctionNamesUpper[spendingFunctionUsed[1]])),sticky="w")
+      tkgrid( tklabel(parametersFrame, text=paste("Function - Lower Bounds: ",FunctionNamesLower[spendingFunctionUsed[2]])),sticky="w")
     }
   }
 
 
-  #drift parameters  
-  tkgrid( tklabel(parametersFrame, text=""),sticky="w") #blank line 
+  #drift parameters
+  tkgrid( tklabel(parametersFrame, text=""),sticky="w") #blank line
   tkgrid( tklabel(parametersFrame, text=paste("Drift =",round(drift,digits=5))),sticky="w")
-  tkgrid( tklabel(parametersFrame, text="Drift is equal to the expectation of the Z statistic when time=1."),sticky="w") 
+  tkgrid( tklabel(parametersFrame, text="Drift is equal to the expectation of the Z statistic when time=1."),sticky="w")
   if(t2max!=0)
   {
     tkgrid( tklabel(parametersFrame, text=paste("Maximum Information =",t2max)),sticky="w")
   }
-  
-  tkgrid( tklabel(parametersFrame, text=""),sticky="w") #blank line 
+
+  tkgrid( tklabel(parametersFrame, text=""),sticky="w") #blank line
 
 
   #create head labels
@@ -124,7 +124,7 @@ function(K,probTotal,drift,expectedStoppingTime,secondTimeScaleIsUsed,t,t2,t2max
   #create labels with results
   for(i in 1:K)
   {
-    tkgrid( tklabel(numbersFrame, text=as.character(i)),sticky="w")  
+    tkgrid( tklabel(numbersFrame, text=as.character(i)),sticky="w")
     tkgrid( tklabel(timesFrame, text=as.character(round(t[i],digits=3))),sticky="w")
     tkgrid( tklabel(secondTimesFrame, text=as.character(round(t2[i],digits=3))),sticky="w")
     tkgrid( tklabel(lowerBoundsFrame, text=as.character(round(lowerBounds[i],digits=4))),sticky="w")
@@ -146,15 +146,15 @@ function(K,probTotal,drift,expectedStoppingTime,secondTimeScaleIsUsed,t,t2,t2max
   }
   tkgrid(staticFrame,sticky="w")
   tkgrid(dynamicFrame,sticky="w")
-  
-   
-  ###########################################################################  
+
+
+  ###########################################################################
   ##function handles click onto button to show results of bounds in a graph##
   ###########################################################################
   onShowGraph <- function()
   {
     if(enterBoundsManually)
-    { 
+    {
       ## if one-Sided-Test we wont see negative Z-Values
       if(BoundsSymmetry==1)
       {
@@ -187,8 +187,8 @@ function(K,probTotal,drift,expectedStoppingTime,secondTimeScaleIsUsed,t,t2,t2max
         lines(t,upperBounds,col="blue")
       }
     }# endif 'if(enterBoundsManually)'
-  
-    else # spending function was used 
+
+    else # spending function was used
     {
     ## if one-Sided-Test we wont see negative Z-Values
       if(BoundsSymmetry==1)
@@ -228,44 +228,44 @@ function(K,probTotal,drift,expectedStoppingTime,secondTimeScaleIsUsed,t,t2,t2max
              pch=21,bg="green",font=4,font.axis=4,font.lab=4,font.main=4, cex.main=0.9,
              xlab="Times",ylab="Standardized Z-Value",ylim=c(-4,4))
         }
-        
+
         ##...then add lines between them
         lines(t,lowerBounds,col="blue")
         lines(t,upperBounds,col="blue")
       }
-    }  
+    }
   }
-  
-################################################################## 
+
+##################################################################
   ## function handles click onto button to save results in a file ##
   ##################################################################
   onSave <- function()
   {
-     #create file variable  
+     #create file variable
      fileName <- tclvalue(tkgetSaveFile(initialfile=".html",filetypes="{{html Files} {.html}} {{All files} *}"))
      if (fileName=="") return;
-     
+
      #open file
      zz <- file(fileName,"w")
-     
+
      #output will be writed in HTML
      cat("<html> <body> \n",file = zz)
-     
+
      #output K
      cat("K=",K,"<br> \n",file = zz)
-     
+
      ##ouput alpha
      if(!enterBoundsManually)
      {
        if(!BoundsSymmetry==3)
        {
          cat("&alpha; =",alpha[1],"<br>\n",file = zz)
-       } 
+       }
        else
        {
          cat("Upper &alpha; = ",alpha[1],"<br>\n",file = zz)
          cat("Lower &alpha; = ",alpha[2],"<br>\n",file = zz)
-       } 
+       }
      }
      if(!BoundsSymmetry==3)
      {
@@ -278,13 +278,13 @@ function(K,probTotal,drift,expectedStoppingTime,secondTimeScaleIsUsed,t,t2,t2max
          ##output names of spending functions that were used
          FunctionNames <- c("O'Brien-Fleming Type","Pocock Type",paste("Power Family: &alpha;&sdot;t<sup>",phi[1],"</sup>"),
                           paste("Hwang-Shih-DeCani Family ( phi =",phi[1],")"),"Exact Pocock Bounds")
-       
+
          # substitute according funtion in output
          cat("<b>",FunctionNames[spendingFunctionUsed[1]],"</b>"," was used as spending Function.","<br>\n",file = zz)
        }
      }
      else
-     {       
+     {
        if(enterBoundsManually)
        {
          cat("UPPER Bounds: <b>manually entered</b> <br>\n",file = zz)
@@ -296,14 +296,14 @@ function(K,probTotal,drift,expectedStoppingTime,secondTimeScaleIsUsed,t,t2,t2max
          FunctionNamesUpper <- c("O'Brien-Fleming Type","Pocock Type",paste("Power Family: &alpha;&sdot;t<sup>",phi[1],"</sup>"),
                           paste("Hwang-Shih-DeCani Family ( phi =",phi[1],")"),"Exact Pocock Bounds")
          FunctionNamesLower <- c("O'Brien-Fleming Type","Pocock Type",paste("Power Family: &alpha;&sdot;t<sup>",phi[2],"</sup>"),
-                          paste("Hwang-Shih-DeCani Family ( phi =",phi[2],")"),"Exact Pocock Bounds")                      
-       
-         # substitute according funtion in output                     
+                          paste("Hwang-Shih-DeCani Family ( phi =",phi[2],")"),"Exact Pocock Bounds")
+
+         # substitute according funtion in output
          cat("Spending Function for UPPER Bound:","<b>",FunctionNamesUpper[spendingFunctionUsed[1]],"</b>","<br>\n",file = zz)
          cat("Spending Function for LOWER Bound:","<b>",FunctionNamesLower[spendingFunctionUsed[2]],"</b>","<br>\n",file = zz)
        }
-     } 
-    
+     }
+
      #drift parameters
      cat("drift=",round(drift,digits=5),"<br> \n",file=zz)
      cat("Drift is equal to the expectation of the Z statistic when time=1.<br> \n",file=zz)
@@ -311,8 +311,8 @@ function(K,probTotal,drift,expectedStoppingTime,secondTimeScaleIsUsed,t,t2,t2max
      {
        cat("Maximum Information=",t2max,"<br> \n",file=zz)
      }
-    
-         
+
+
      ##output the bounds
      #labels
      cat("<br>\n",file = zz)
@@ -323,24 +323,24 @@ function(K,probTotal,drift,expectedStoppingTime,secondTimeScaleIsUsed,t,t2,t2max
      cat("<td>Lower Bounds &#160</td>  <td>Upper Bounds &#160</td> \n",file = zz)
      cat("<td>Exit Probability &#160</td>  <td>Cumulative Exit Prob. &#160</td> \n",file = zz)
      cat("</tr> \n",file = zz)
-     
+
      #values
      for(i in 1:K)
      {
        cat("<tr> \n",file = zz)
-       cat("<td>",round(t[i],digits=3),"</td> \n",file = zz ) 
+       cat("<td>",round(t[i],digits=3),"</td> \n",file = zz )
        if(secondTimeScaleIsUsed) { cat("<td>",round(t2[i],digits=3),"</td> \n",file = zz ) }
-       cat("<td>",round(lowerBounds[i],digits=4),"</td>",   "<td>",round(upperBounds[i],digits=4),"</td>", 
+       cat("<td>",round(lowerBounds[i],digits=4),"</td>",   "<td>",round(upperBounds[i],digits=4),"</td>",
            "<td>",round(resultExitProb[i],digits=10),"</td>",   "<td>",round(cumulativeExitProb[i],digits=10),"</td> \n",file = zz )
-       cat("</tr> \n",file = zz)    
+       cat("</tr> \n",file = zz)
      }
-     
+
      cat("</table> \n",file = zz)
      cat("</body> </html> \n",file = zz)
      close(zz)
   }
 
-  
+
   ###########################################################################
   ##function handles click onto button to Cancel i.e. close current window ##
   ###########################################################################
@@ -368,11 +368,11 @@ function(K,probTotal,drift,expectedStoppingTime,secondTimeScaleIsUsed,t,t2,t2max
          cancel.button, sticky="we")
   tkgrid(buttonFrame)
   tkgrid( tklabel(buttonFrame, text=""))   #blank line
-  
+
   #grid allover frame and focus
   tkgrid(OutputTask3,sticky="w")
   tkfocus(outTask3Toplevel)
-       
-   
-   
+
+
+
 }#end <--*function(...)*
